module.exports = defineTest({
	description: 'correctly associates pure comments before sequence expressions etc.'
});
